PayPlatform class abstract

A contract that defines the required actions for payment libraries that implement it.

Implementers

Constructors

PayPlatform()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showPaymentSelector(PaymentConfiguration paymentConfiguration, List<PaymentItem> paymentItems) → Future<Map<String, dynamic>>
Triggers the action to show the payment selector to complete a payment with the configuration and a list of PaymentItem that help determine the price elements to show in the payment selector.
toString() → String
A string representation of this object.
inherited
userCanPay(PaymentConfiguration paymentConfiguration) → Future<bool>
Determines whether the caller can make a payment with a given configuration.

Operators

operator ==(Object other) → bool
The equality operator.
inherited