Configurations class

A utility class to handle configuration objects and metadata associated with this plugin.

Constructors

Configurations()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

extractParameters(Map<String, dynamic> configuration) → Future<Map<String, dynamic>>
Complements the payment configuration object with metadata about the package.